@@ -49,7 +49,7 @@ class cached_property(object):
         return value
 
 def cached_method(func):
-    """Decorator that caches a function's return value each time it is called.
+    """Decorator that caches a method's return value each time it is called.
     If called later with the same arguments, the cached value is returned, and
     not re-evaluated.
     """
@@ -70,6 +70,29 @@ def cached_method(func):
     callee.__cached_method__ = True
     return callee
 
+def cached_function(func):
+    """Decorator that caches a function's return value each time it is called.
+    If called later with the same arguments, the cached value is returned, and
+    not re-evaluated.
+    """
+    def make_key(args, kwargs):
+        return (tuple(args), frozenset(kwargs.iteritems()))
+    
+    @wraps(func)
+    def callee(*args, **kwargs):
+        key = make_key(args, kwargs)
+        try:
+            value = func._cache[key]
+        except (KeyError, AttributeError):
+            value = func(*args, **kwargs)
+            if not hasattr(func, '_cache'):
+                setattr(func, '_cache', {})
+            func._cache[key] = value
+        return value
+
+    callee.__cached_method__ = True
+    return callee
+
 def clear_cache(self):
     if hasattr(self, '_cache'):
         getattr(self, '_cache').clear()
@@ -120,4 +143,3 @@ class LazyImmutableDict(object):
 
     def _create_value(self, key):
         raise NotImplementedError()
-
